@@ -1,6 +1,7 @@
 # system configuration generated and used by the sysconfig module
 build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
+ 'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
@@ -10,60 +11,74 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
- 'BINLIBDEST': '/usr/lib/python3.8',
- 'BLDLIBRARY': '-L. -lpython3.8',
- 'BLDSHARED': 'gcc -shared -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
-              '-Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs '
-              '-flto=auto -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
-              '-Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs '
-              '-flto=auto',
- 'BUILDEXE': '',
- 'BUILDPYTHON': 'python',
+ 'BINLIBDEST': '/usr/lib/python3.9',
+ 'BLDLIBRARY': '-L. -lpython3.9',
+ 'BLDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+              '-fno-semantic-interposition '
+              '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'BUILDEXE': '.exe',
+ 'BUILDPYTHON': 'python.exe',
  'BUILD_GNU_TYPE': 'x86_64-pc-linux-gnu',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-           '-DOPENSSL_NO_SSL2 -march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
-           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+           '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
            '-Werror=format-security         -fstack-clash-protection '
-           '-fcf-protection         -fno-omit-frame-pointer '
-           '-mno-omit-leaf-frame-pointer -flto=auto',
+           '-fcf-protection -fno-semantic-interposition -march=x86-64 '
+           '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
+           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
+           '-fstack-clash-protection -fcf-protection -march=x86-64 '
+           '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
+           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
+           '-fstack-clash-protection -fcf-protection',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-DOPENSSL_NO_SSL2',
- 'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
-                            '-Wno-unused-parameter '
+ 'CONFIGURE_CFLAGS': '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                     '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                     '-Werror=format-security         -fstack-clash-protection '
+                     '-fcf-protection -fno-semantic-interposition',
+ 'CONFIGURE_CFLAGS_NODIST': '-flto=4 -fuse-linker-plugin -ffat-lto-objects '
+                            '-flto-partition=none -g -std=c99 -Wextra '
+                            '-Wno-unused-result -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
-                            '-Werror=implicit-function-declaration',
+                            '-Werror=implicit-function-declaration '
+                            '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
- 'CONFIGURE_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
-                      '-Wl,-z,now          -Wl,-z,pack-relative-relocs '
-                      '-flto=auto',
- 'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-threads' "
-                "'--with-computed-gotos' '--enable-ipv6' '--with-system-expat' "
-                "'--with-dbmliborder=gdbm:ndbm' '--with-system-libmpdec' "
+ 'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+                      '-fno-semantic-interposition',
+ 'CONFIGURE_LDFLAGS_NODIST': '-flto=4 -fuse-linker-plugin -ffat-lto-objects '
+                             '-flto-partition=none -g',
+ 'CONFIG_ARGS': "'--prefix=/usr' '-enable-shared' '--with-computed-gotos' "
+                "'--with-lto' '--enable-ipv6' '--with-system-expat' "
+                "'--with-dbmliborder=gdbm:ndbm' '--with-system-ffi' "
+                "'--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
-                "'CFLAGS=-DOPENSSL_NO_SSL2' 'LDFLAGS=-Wl,-O1 -Wl,--sort-common "
-                '-Wl,--as-needed -Wl,-z,relro -Wl,-z,now          '
-                "-Wl,-z,pack-relative-relocs -flto=auto'",
+                "'--with-tzpath=/usr/share/zoneinfo' "
+                "'ax_cv_c_float_words_bigendian=no' 'CFLAGS=-march=x86-64 "
+                '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
+                '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                '-Werror=format-security         -fstack-clash-protection '
+                "-fcf-protection -fno-semantic-interposition' "
+                "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now "
+                "-fno-semantic-interposition'",
  'CONFINCLUDEDIR': '/usr/include',
- 'CONFINCLUDEPY': '/usr/include/python3.8',
+ 'CONFINCLUDEPY': '/usr/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/home/pkguser/.cache/aurutils/sync/python38/src/Python-3.8.20/coverage.info',
- 'COVERAGE_REPORT': '/home/pkguser/.cache/aurutils/sync/python38/src/Python-3.8.20/lcov-report',
+ 'COVERAGE_INFO': '/data/tmp/aur-temp/python39/src/Python-3.9.9/coverage.info',
+ 'COVERAGE_REPORT': '/data/tmp/aur-temp/python39/src/Python-3.9.9/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include',
  'CXX': 'g++',
- 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.8 /usr/lib/python3.8/lib-dynload',
- 'DESTLIB': '/usr/lib/python3.8',
+ 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.9 /usr/lib/python3.9/lib-dynload',
+ 'DESTLIB': '/usr/lib/python3.9',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/lib/python3.8/lib-dynload',
+ 'DESTSHARED': '/usr/lib/python3.9/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -85,14 +100,14 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
+ 'EXPORTSFROM': '',
+ 'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
- 'EXTRA_CFLAGS': '',
- 'EXT_SUFFIX': '.cpython-38-x86_64-linux-gnu.so',
+ 'EXT_SUFFIX': '.cpython-39-x86_64-linux-gnu.so',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
- 'GETTIMEOFDAY_NO_TZ': 0,
  'GITBRANCH': '',
  'GITTAG': '',
  'GITVERSION': '',
@@ -248,7 +263,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GETSID': 1,
  'HAVE_GETSPENT': 1,
  'HAVE_GETSPNAM': 1,
- 'HAVE_GETTIMEOFDAY': 1,
  'HAVE_GETWD': 1,
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
@@ -280,18 +294,22 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBSENDFILE': 0,
  'HAVE_LIBUTIL_H': 0,
+ 'HAVE_LIBUUID': 1,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
  'HAVE_LINUX_CAN_BCM_H': 1,
  'HAVE_LINUX_CAN_H': 1,
+ 'HAVE_LINUX_CAN_J1939_H': 1,
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 1,
  'HAVE_LINUX_CAN_RAW_H': 1,
+ 'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 1,
  'HAVE_LINUX_MEMFD_H': 1,
  'HAVE_LINUX_NETLINK_H': 1,
  'HAVE_LINUX_QRTR_H': 1,
  'HAVE_LINUX_RANDOM_H': 1,
  'HAVE_LINUX_TIPC_H': 1,
  'HAVE_LINUX_VM_SOCKETS_H': 1,
+ 'HAVE_LINUX_WAIT_H': 1,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
@@ -317,6 +335,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_NETPACKET_PACKET_H': 1,
  'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
+ 'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
  'HAVE_OPENAT': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_PATHCONF': 1,
@@ -343,7 +362,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PTHREAD_KILL': 1,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 1,
- 'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
  'HAVE_PWRITEV2': 1,
@@ -368,6 +386,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SCHED_SETAFFINITY': 1,
  'HAVE_SCHED_SETPARAM': 1,
  'HAVE_SCHED_SETSCHEDULER': 1,
+ 'HAVE_SEM_CLOCKWAIT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
@@ -422,7 +441,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
- 'HAVE_STRLCPY': 1,
+ 'HAVE_STRLCPY': 0,
  'HAVE_STROPTS_H': 0,
  'HAVE_STRSIGNAL': 1,
  'HAVE_STRUCT_PASSWD_PW_GECOS': 1,
@@ -495,7 +514,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 1,
- 'HAVE_UNSETENV': 1,
  'HAVE_USABLE_WCHAR_T': 0,
  'HAVE_UTIL_H': 0,
  'HAVE_UTIMENSAT': 1,
@@ -521,43 +539,40 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'x86_64-pc-linux-gnu',
- 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.8 '
-                   '/usr/include/python3.8',
+ 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.9 '
+                   '/usr/include/python3.9',
  'INCLUDEDIR': '/usr/include',
- 'INCLUDEPY': '/usr/include/python3.8',
- 'INSTALL': '/usr/bin/install -c',
- 'INSTALL_DATA': '/usr/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/usr/bin/install -c',
- 'INSTALL_SCRIPT': '/usr/bin/install -c',
- 'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'libpython3.8.so.1.0',
+ 'INCLUDEPY': '/usr/include/python3.9',
+ 'INSTALL': '/bin/install -c',
+ 'INSTALL_DATA': '/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/bin/install -c',
+ 'INSTALL_SCRIPT': '/bin/install -c',
+ 'INSTALL_SHARED': '/bin/install -c -m 755',
+ 'INSTSONAME': 'libpython3.9.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -shared',
- 'LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
-            '-Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto '
-            '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
-            '-Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto',
+ 'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+            '-fno-semantic-interposition '
+            '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.8.so',
+ 'LDLIBRARY': 'libpython3.9.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -shared -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
-             '-Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs '
-             '-flto=auto -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
-             '-Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs '
-             '-flto=auto',
- 'LDVERSION': '3.8',
+ 'LDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+             '-fno-semantic-interposition '
+             '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'LDVERSION': '3.9',
  'LIBC': '',
- 'LIBDEST': '/usr/lib/python3.8',
+ 'LIBDEST': '/usr/lib/python3.9',
  'LIBDIR': '/usr/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/lib/pkgconfig',
- 'LIBPL': '/usr/lib/python3.8/config-3.8-x86_64-linux-gnu',
+ 'LIBPL': '/usr/lib/python3.9/config-3.9-x86_64-linux-gnu',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.8.a',
+ 'LIBRARY': 'libpython3.9.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lcrypt -ldl  -lm',
@@ -573,18 +588,18 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/lib/python3.8',
+ 'MACHDESTLIB': '/usr/lib/python3.9',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/share/man',
- 'MKDIR_P': '/usr/bin/mkdir -p',
+ 'MKDIR_P': '/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
                    '_stat  time  _thread  _locale  _io  faulthandler  '
-                   '_tracemalloc  _symtable  xxsubtype',
+                   '_tracemalloc  _peg_parser  _symtable  xxsubtype',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
  'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
@@ -597,7 +612,7 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
             'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
             'Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o Modules/hashtable.o  '
+            'Modules/_tracemalloc.o  Modules/_peg_parser.o  '
             'Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': 'x86_64-linux-gnu',
@@ -617,14 +632,18 @@ build_time_vars = {'ABIFLAGS': '',
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/parsetok.o '
+                'Parser/tokenizer.o',
+ 'PEGEN_HEADERS': '\\',
+ 'PEGEN_OBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
  'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
+ 'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test --pgo',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
- 'PTHREAD_SYSTEM_SCHED_SUPPORTED': 0,
+ 'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
  'PY3LIBRARY': 'libpython3.so',
  'PYLONG_BITS_IN_DIGIT': 0,
@@ -634,70 +653,103 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
- 'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3',
+ 'PYTHON_FOR_BUILD': './python.exe -E',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
-                             '-fwrapv -O3 -Wall -DOPENSSL_NO_SSL2 '
-                             '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
-                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
+                             '-fwrapv -O3 -Wall -march=x86-64 -mtune=generic '
+                             '-O3 -pipe -fno-plt -fexceptions         '
+                             '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                             '-Werror=format-security         '
+                             '-fstack-clash-protection -fcf-protection '
+                             '-fno-semantic-interposition -march=x86-64 '
+                             '-mtune=generic -O3 -pipe -fno-plt '
+                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -fcf-protection         '
-                             '-fno-omit-frame-pointer '
-                             '-mno-omit-leaf-frame-pointer -flto=auto -std=c99 '
-                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                             '-fstack-clash-protection -fcf-protection '
+                             '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-Wformat -Werror=format-security         '
+                             '-fstack-clash-protection -fcf-protection -flto=4 '
+                             '-fuse-linker-plugin -ffat-lto-objects '
+                             '-flto-partition=none -g -std=c99 -Wextra '
+                             '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
-                             '-Werror=implicit-function-declaration  '
-                             '-I./Include/internal -I. -I./Include -fPIC '
-                             '-DPy_BUILD_CORE_BUILTIN',
+                             '-Werror=implicit-function-declaration '
+                             '-fvisibility=hidden  -I./Include/internal -I. '
+                             '-I./Include -fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-              '-DOPENSSL_NO_SSL2 -march=x86-64 -mtune=generic -O2 -pipe '
-              '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+              '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
               '-Werror=format-security         -fstack-clash-protection '
-              '-fcf-protection         -fno-omit-frame-pointer '
-              '-mno-omit-leaf-frame-pointer -flto=auto',
- 'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
-                     '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Werror=implicit-function-declaration  '
-                     '-I./Include/internal',
+              '-fcf-protection -fno-semantic-interposition -march=x86-64 '
+              '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
+              '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+              '-Werror=format-security         -fstack-clash-protection '
+              '-fcf-protection -march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+              '-Werror=format-security         -fstack-clash-protection '
+              '-fcf-protection',
+ 'PY_CFLAGS_NODIST': '-flto=4 -fuse-linker-plugin -ffat-lto-objects '
+                     '-flto-partition=none -g -std=c99 -Wextra '
+                     '-Wno-unused-result -Wno-unused-parameter '
+                     '-Wno-missing-field-initializers '
+                     '-Werror=implicit-function-declaration '
+                     '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
-                   '-Wall -DOPENSSL_NO_SSL2 -march=x86-64 -mtune=generic -O2 '
-                   '-pipe -fno-plt -fexceptions         '
-                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+                   '-Wall -march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                   '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-fcf-protection         -fno-omit-frame-pointer '
-                   '-mno-omit-leaf-frame-pointer -flto=auto -std=c99 -Wextra '
-                   '-Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers '
-                   '-Werror=implicit-function-declaration  '
+                   '-fcf-protection -fno-semantic-interposition -march=x86-64 '
+                   '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-Werror=format-security         -fstack-clash-protection '
+                   '-fcf-protection -march=x86-64 -mtune=generic -O3 -pipe '
+                   '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                   '-Wformat -Werror=format-security         '
+                   '-fstack-clash-protection -fcf-protection -flto=4 '
+                   '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none '
+                   '-g -std=c99 -Wextra -Wno-unused-result '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
-                    '-Wl,-z,now          -Wl,-z,pack-relative-relocs '
-                    '-flto=auto -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
-                    '-Wl,-z,relro -Wl,-z,now          '
-                    '-Wl,-z,pack-relative-relocs -flto=auto',
+ 'PY_CORE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+                    '-fno-semantic-interposition '
+                    '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -flto=4 '
+                    '-fuse-linker-plugin -ffat-lto-objects '
+                    '-flto-partition=none -g',
  'PY_CPPFLAGS': '-I. -I./Include',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
-               '-Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto '
-               '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
-               '-Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto',
- 'PY_LDFLAGS_NODIST': '',
+ 'PY_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+               '-fno-semantic-interposition '
+               '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'PY_LDFLAGS_NODIST': '-flto=4 -fuse-linker-plugin -ffat-lto-objects '
+                      '-flto-partition=none -g',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
-                        '-O3 -Wall -DOPENSSL_NO_SSL2 -march=x86-64 '
-                        '-mtune=generic -O2 -pipe -fno-plt '
-                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+                        '-O3 -Wall -march=x86-64 -mtune=generic -O3 -pipe '
+                        '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                        '-Wformat -Werror=format-security         '
+                        '-fstack-clash-protection -fcf-protection '
+                        '-fno-semantic-interposition -march=x86-64 '
+                        '-mtune=generic -O3 -pipe -fno-plt '
+                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -fcf-protection         '
-                        '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
-                        '-flto=auto -std=c99 -Wextra -Wno-unused-result '
-                        '-Wno-unused-parameter -Wno-missing-field-initializers '
-                        '-Werror=implicit-function-declaration  '
-                        '-I./Include/internal -I. -I./Include -fPIC',
+                        '-fstack-clash-protection -fcf-protection '
+                        '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                        '-Werror=format-security         '
+                        '-fstack-clash-protection -fcf-protection -flto=4 '
+                        '-fuse-linker-plugin -ffat-lto-objects '
+                        '-flto-partition=none -g -std=c99 -Wextra '
+                        '-Wno-unused-result -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers '
+                        '-Werror=implicit-function-declaration '
+                        '-fvisibility=hidden  -I./Include/internal -I. '
+                        '-I./Include -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -706,10 +758,9 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/home/pkguser/.cache/aurutils/sync/python38/src/Python-3.8.20',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/data/tmp/aur-temp/python39/src/Python-3.9.9',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
- 'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
  'SHLIBS': '-lcrypt -ldl  -lm',
  'SHLIB_SUFFIX': '.so',
@@ -734,8 +785,8 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-38-x86_64-linux-gnu',
- 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
+ 'SOABI': 'cpython-39-x86_64-linux-gnu',
+ 'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -748,21 +799,22 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/pkguser/.cache/aurutils/sync/python38/src/Python-3.8.20 '
-               './python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/data/tmp/aur-temp/python39/src/Python-3.9.9 '
+               './python.exe',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/pkguser/.cache/aurutils/sync/python38/src/Python-3.8.20 '
-               './python ./Tools/scripts/run_tests.py',
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/data/tmp/aur-temp/python39/src/Python-3.9.9 '
+               './python.exe ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
+ 'TZPATH': '/usr/share/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
- 'VERSION': '3.8',
- 'WINDOW_HAS_FLAGS': 0,
+ 'VERSION': '3.9',
+ 'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
@@ -773,8 +825,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/pkguser/.cache/aurutils/sync/python38/src/Python-3.8.20',
- 'abs_srcdir': '/home/pkguser/.cache/aurutils/sync/python38/src/Python-3.8.20',
+ 'abs_builddir': '/data/tmp/aur-temp/python39/src/Python-3.9.9',
+ 'abs_srcdir': '/data/tmp/aur-temp/python39/src/Python-3.9.9',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
